/*
 * PCF8523_RTCC.h
 *
 *  Created on: 2022. nov. 2.
 *      Author: BB
 */

#include <ti/drivers/I2C.h>
#include <ti/display/Display.h>

// Slave address
//#define PCF8523_I2C_ADDRESS 0xE0				// 0xE0 is in Read mode: 0b 1101 000 0(R/-W)
#define PCF8523_I2C_ADDRESS 0x68				// 0x68 is in Read mode: 0b 0110 100 0(R/-W)

// *************************************/
// PCF8523 Register Definitions
// *************************************/
												// BITS
// Control registers							// 7		6		5		4		3		2		1		0
#define PCF8523_RCTT_CONTROL_1			0x00	// CAP_SEL	T		STOP	SR		12_24	SIE		AIE		CIE
#define PCF8523_RCTT_CONTROL_2			0x01	// WTAF		CTAF	CTBF	SF		AF		WTAIE	CTAIE	CTBIE
#define PCF8523_RCTT_CONTROL_3			0x02	// [PM 0...7			]	-		BSF		BLF		BSIE	BLIE

// Time and date registers
#define PCF8523_RCTT_SECONDS 			0x03	// OS		[SECONDS 0...59										]
#define PCF8523_RCTT_MINUTES 			0x04	// -		[MINUTES 0...59										]
#define PCF8523_RCTT_HOURS	 			0x05	// -		-		AMPM	[HOURS 1...12 in 12h mode			]
												// -		-		[HOURS 0...23 in 24h mode					]
#define PCF8523_RCTT_DAYS	 			0x06	// -		-		[DAYS 1...31								]
#define PCF8523_RCTT_WEEKDAYS 			0x07	// -		-		-		-		-		[WEEKDAYS 0...6		]
#define PCF8523_RCTT_MONTHS 			0x08	// -		-		-		[MONTHS 1...12						]
#define PCF8523_RCTT_YEARS	 			0x09	// [YEARS 0...99												]

// Alarm registers
#define PCF8523_RCTT_MINUTE_ALARM		0x0A	// AEN_M	[MINUTE_ALARM 0...59								]
#define PCF8523_RCTT_HOUR_ALARM			0x0B	// AEN_H	-		AMPM	[HOURS 1...12 in 12h mode			]
												// AEN_H	-		[HOURS 0...23 in 24h mode					]
#define PCF8523_RCTT_DAY_ALARM			0x0C	// AEN_D	-		[DAY_ALARM 1...31							]
#define PCF8523_RCTT_WEEKDAY_ALARM		0x0D	// AEN_W	-		-		-		-		[WEEKDAY_ALARM 0...6]

// Offset register
#define PCF8523_RCTT_OFFSET				0x0E	// MODE		[OFFSET	0...127										]

// CLKOUT and timer registers
#define PCF8523_RCTT_TMR_CLKOUT_CTRL	0x0F	// TAM		TBM		[COF 0...7			]	[TAC 0...3	]	TBC
#define PCF8523_RCTT_TMR_A_FREQ_CTRL	0x10	// -		-		-		-		-		[TAQ 0...7			]
#define PCF8523_RCTT_TMR_A_REG			0x11	// [T_A 0...255													]
#define PCF8523_RCTT_TMR_B_FREQ_CTRL	0x12	// -		[TBW 0...7			]	-		[TBQ 0...7			]
#define PCF8523_RCTT_TMR_B_REG			0x13	// [T_B 0...255													]

// Software reset: Send 3 bytes: 0xE0; 0x00; 0x58 (Slave address; Address 0x00; SW Reset CMD 0x58)

// *************************************/
// PCF8523 Function Prototypes
// *************************************/

extern void i2cErrorHandler(I2C_Transaction *transaction, Display_Handle display);
